.. _cost_function_guide:

===================
cost function guide
===================

This guide is currently a work in progress and only contains bullet points for now.

Cost Functions in VQAs
======================